const config = require('./config');

const winston = require('winston');

winston.emitErrs = true;

function getFilePath(module) {
    // using filename in log statements
    return module.filename.split('/').slice(-2).join('/');
}

function logger(module) {
    const log = new winston.Logger({
        transports: [
            new winston.transports.File({
                name: 'info-log',
                level: 'info',
                filename: `${process.cwd()}/logs/all.log`,
                handleException: true,
                json: false,
                maxSize: 5242880, // 5MB
                maxFiles: 2,
                colorize: false,
            }),
            new winston.transports.Console({
                name: 'debug-log',
                level: 'debug',
                label: getFilePath(module),
                handleException: true,
                json: false,
                colorize: true,
            }),
        ],
        exitOnError: false,
    });
    if (!config.get('debug')) {
        log.remove('debug-log');
    }
    return log;
}

module.exports = logger;
